<?xml version="1.0"?>

<!--
  XSL for generating HTML from XML specified according to doc.dtd.

  $Id: doc2html.xsl,v 1.22 2004/02/04 14:01:20 just Exp $
-->

<!DOCTYPE xsl:stylesheet [
	<!-- space -->
	<!ENTITY sp "&#160;">
]>


<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:lxslt="http://xml.apache.org/xslt"
	xmlns:redirect="org.apache.xalan.xslt.extensions.Redirect"
    xmlns:java="http://xml.apache.org/xslt/java"
    exclude-result-prefixes="java"
	extension-element-prefixes="redirect">

<xsl:output method="html" indent="yes" encoding="ISO-8859-1" />

<xsl:include href="nl/justobjects/xbook/rsc/xsl/text2html.xsl"/>

<xsl:param name="STYLEFILE" select="'nl/justobjects/xbook/rsc/skin/default-doc-style.xml'"/>
<xsl:param name="OUTFILE" select="'no-htmlfile-supplied.html'"/>
<xsl:param name="OUTDIR" select="'.'"/>

<!-- derived filenames (not full paths!) -->
<xsl:variable name="BASEFILE"><xsl:value-of select="substring-before($OUTFILE, '.htm')"/></xsl:variable>
<xsl:variable name="COVERFILE"><xsl:value-of select="$OUTFILE"/></xsl:variable>
<xsl:variable name="REFSFILE"><xsl:value-of select="concat($BASEFILE, '-refs', '.html')"/></xsl:variable>
<xsl:variable name="TOCFILE"><xsl:value-of select="concat($BASEFILE, '-toc', '.html')"/></xsl:variable>
<xsl:variable name="PRINTFILE"><xsl:value-of select="concat($BASEFILE, '-all', '.html')"/></xsl:variable>

<xsl:variable name="BASEFILEPATH"><xsl:value-of select="concat($OUTDIR, '/', $BASEFILE)"/></xsl:variable>
<xsl:variable name="REFSFILEPATH"><xsl:value-of select="concat($BASEFILEPATH, '-refs', '.html')"/></xsl:variable>
<xsl:variable name="TOCFILEPATH"><xsl:value-of select="concat($BASEFILEPATH, '-toc', '.html')"/></xsl:variable>
<xsl:variable name="PRINTFILEPATH"><xsl:value-of select="concat($BASEFILEPATH, '-all', '.html')"/></xsl:variable>

<!-- Process top -->
<xsl:template match="/doc">
	<xsl:variable name="enableMultipleOutputFiles" select="java:nl.justobjects.xbook.XSLTHelper.enableMultipleOutputFiles()" />
	<xsl:apply-templates select="front"/>
	<xsl:apply-templates select="middle"/>
	<xsl:apply-templates select="back"/>

	<!-- Generates all-in-in-one version -->
	<redirect:write select="$PRINTFILEPATH">
	    <xsl:variable name="dummy" select="java:nl.justobjects.xbook.XSLTHelper.setVar('destFile', $PRINTFILE)" />
		<html lang="en">

		<xsl:call-template name="head">
			<xsl:with-param name="TITLE" select="front/title"/>
		</xsl:call-template>

		<body marginwidth="0">
			<xsl:call-template name="cover" />
		 	<xsl:for-each select="middle/section1">
				<xsl:call-template name="section1"/>
			</xsl:for-each>

		<xsl:if test="/doc/back">
			<xsl:call-template name="refs" />
		</xsl:if>
	    </body>
	    </html>

	</redirect:write>

</xsl:template>

<!-- Process front matter -->
<xsl:template match="front">
	<html lang="en">

	<xsl:call-template name="head">
		<xsl:with-param name="TITLE" select="title"/>
	</xsl:call-template>

	<body marginwidth="0">
		<xsl:call-template name="cover" />
		<table cellspacing="0" cellpadding="12" border="0" >
			<tr>
				<td>
					<div class="MAIN">
 						<a href="{$TOCFILE}">Table of Contents</a>
					</div>
				</td>
			</tr>
			<xsl:if test="/doc/back">
				<tr>
					<td>
						<div class="MAIN">
							<a href="{$REFSFILE}">References</a>
						</div>
					</td>
				</tr>
			</xsl:if>
			<tr>
				<td>
					<div class="MAIN">
 						<a href="{$PRINTFILE}">All-in-one Printer Version (HTML)</a>
					</div>
				</td>
			</tr>
		</table>

    </body>
    </html>

	<redirect:write select="$TOCFILEPATH">
		<html>
			<xsl:call-template name="head">
				<xsl:with-param name="TITLE" select="'Contents'"/>
			</xsl:call-template>

            <body marginwidth="0">
				<xsl:call-template name="nav"/>
				<hr/>
				<xsl:call-template name="toc" />
    			<hr/>
				<xsl:call-template name="nav"/>
			</body>
		</html>
	</redirect:write>
</xsl:template>

<!-- Middle: let text rules handle this (sections, para's etc) -->
<xsl:template match="middle">
 	<xsl:for-each select="section1">
    <xsl:variable name="destFile" select="concat($BASEFILE, '-s', position(), '.html')" />
	<xsl:variable name="dummy" select="java:nl.justobjects.xbook.XSLTHelper.setVar('destFile', $destFile)" />
		<redirect:write select="concat($BASEFILEPATH, '-s', position(), '.html')">
			<html>
				<xsl:call-template name="head">
					<xsl:with-param name="TITLE" select="@title"/>
				</xsl:call-template>

	            <body marginwidth="0">
					<xsl:call-template name="nav"/>
					<hr/>
					<xsl:call-template name="section1"/>
					<hr/>
					<xsl:call-template name="nav"/>
				</body>
			</html>
		</redirect:write>
	</xsl:for-each>
</xsl:template>

<!-- Back: mainly refs -->
<xsl:template match="back">
	<redirect:write select="$REFSFILEPATH">
		<html>
		<xsl:call-template name="head">
			<xsl:with-param name="TITLE" select="'References'"/>
		</xsl:call-template>
	    <body marginwidth="0">
		    <xsl:call-template name="nav"/>
		    <hr/>
		    <xsl:call-template name="refs"/>
		    <hr/>
		    <xsl:call-template name="nav"/>
		</body>
		</html>
	</redirect:write>
</xsl:template>


<!-- Overrule template from text2html.xsl -->
<xsl:template match="section2" priority="2" >
	<xsl:call-template name="processAnchor">
		<xsl:with-param name="ANCHORID" select="@id"/>
	</xsl:call-template>
  <xsl:variable name="S2"><xsl:call-template name="setS2"/></xsl:variable>
  <A name="{concat('s', $S2)}" />
     <h2><xsl:value-of select="concat($S2, ' ', @title)"/></h2>
    <div class="MAIN">
    <xsl:apply-templates/>
   </div>
</xsl:template>

<!-- Overrule template from text2html.xsl -->
<xsl:template match="section3" priority="2" >
	<xsl:call-template name="processAnchor">
		<xsl:with-param name="ANCHORID" select="@id"/>
	</xsl:call-template>
  <xsl:variable name="S3"><xsl:call-template name="setS3"/></xsl:variable>
  <A name="{concat('s', $S3)}" />
     <h3><xsl:value-of select="concat($S3, ' ', @title)"/></h3>
    <div class="MAIN">
    <xsl:apply-templates/>
   </div>
</xsl:template>

<!-- Overrule template from text2html.xsl -->
<xsl:template match="section4" priority="2" >
	<xsl:call-template name="processAnchor">
		<xsl:with-param name="ANCHORID" select="@id"/>
	</xsl:call-template>
  <xsl:variable name="S4"><xsl:call-template name="setS4"/></xsl:variable>
  <A name="{concat('s', $S4)}" />
     <h4><xsl:value-of select="concat($S4, ' ', @title)"/></h4>
    <div class="MAIN">
    <xsl:apply-templates/>
   </div>
</xsl:template>

<!-- Overrule template from text2html.xsl -->
<xsl:template match="section5" priority="2" >
	<xsl:call-template name="processAnchor">
		<xsl:with-param name="ANCHORID" select="@id"/>
	</xsl:call-template>
  <xsl:variable name="S5"><xsl:call-template name="setS5"/></xsl:variable>
  <A name="{concat('s', $S5)}" />
     <h5><xsl:value-of select="concat($S5, ' ', @title)"/></h5>
    <div class="MAIN">
    <xsl:apply-templates/>
   </div>
</xsl:template>

<!-- Overrule template from text2html.xsl -->
<xsl:template match="section6" priority="2" >
	<xsl:call-template name="processAnchor">
		<xsl:with-param name="ANCHORID" select="@id"/>
	</xsl:call-template>
  <xsl:variable name="S6"><xsl:call-template name="setS6"/></xsl:variable>
  <A name="{concat('s', $S6)}" />
     <h6><xsl:value-of select="concat($S6, ' ', @title)"/></h6>
    <div class="MAIN">
    <xsl:apply-templates/>
   </div>
</xsl:template>

<!-- Overrule template from text2html.xsl -->
<xsl:template match="section7" priority="2" >
	<xsl:call-template name="processAnchor">
		<xsl:with-param name="ANCHORID" select="@id"/>
	</xsl:call-template>
  <xsl:variable name="S7"><xsl:call-template name="setS7"/></xsl:variable>
  <A name="{concat('s', $S7)}" />
     <span class="H7"><xsl:value-of select="concat($S7, ' ', @title)"/></span>
    <div class="MAIN">
    <xsl:apply-templates/>
   </div>
</xsl:template>

<!-- Overrule template from text2html.xsl -->
<xsl:template match="section8" priority="2" >
	<xsl:call-template name="processAnchor">
		<xsl:with-param name="ANCHORID" select="@id"/>
	</xsl:call-template>
  <xsl:variable name="S8"><xsl:call-template name="setS8"/></xsl:variable>
  <A name="{concat('s', $S8)}" />
     <span class="H8"><xsl:value-of select="concat($S8, ' ', @title)"/></span>
    <div class="MAIN">
    <xsl:apply-templates/>
   </div>
</xsl:template>


<!--

START CALLABLE TEMPLATES

-->

<!-- Overrule template from text2html.xsl -->
<xsl:template name="section1" priority="2" >
	<xsl:call-template name="processAnchor">
		<xsl:with-param name="ANCHORID" select="@id"/>
	</xsl:call-template>
  <xsl:variable name="S1"><xsl:call-template name="setS1"/></xsl:variable>
  <A name="{concat('s', $S1)}" />
     <h1><xsl:value-of select="concat($S1, ' ', @title)"/></h1>
    <div class="MAIN">
    <xsl:apply-templates/>
   </div>
</xsl:template>

<!-- Cover Generation -->
<xsl:template name="cover">
	<table cellspacing="0" cellpadding="20" border="0" width="60%">
		<tr>
			<td>
			   <div class="TITLE">
			      <xsl:value-of select="/doc/front/title"/>
			   </div>
		   </td>
		</tr>
		<tr>
			<td valign="top">
				<div class="MAIN">
					<xsl:for-each select="/doc/front/author">
						<p>
						<b>Author: </b><xsl:value-of select="name"/><br/>
						<b>Organization: </b> <xsl:value-of select="organization"/><br/>
						<b>Email: </b> <a>
						<xsl:attribute name="href">mailto:<xsl:value-of select="email"/></xsl:attribute>
						<xsl:value-of select="email"/></a><br/>
						</p>
					</xsl:for-each>
					<xsl:if test="/doc/front/id">
						<b>FileID: </b><xsl:value-of select="/doc/front/id"/><br/>
					</xsl:if>
					<b>Date: </b><xsl:value-of select="/doc/front/date"/><br/>
				</div>
			</td>
	    </tr>
		<tr>
			<td >
			   <hr/>
					<p class="ABSTRACT">
						<xsl:value-of select="/doc/front/abstract"/>
					</p>
			    <hr/>
		   </td>
		</tr>
    </table>
</xsl:template>

<!-- TOC Generation -->
<xsl:template name="toc">
   <h2>Contents</h2>
    <xsl:for-each select="/doc/middle/section1">

       <xsl:variable name="S1"><xsl:call-template name="setS1"/></xsl:variable>
	   <xsl:variable name="S1FILE"><xsl:value-of select="concat($BASEFILE,'-s',position(),'.html')"/></xsl:variable>
       <a href="{$S1FILE}"><xsl:value-of select="concat($S1, ' ', @title)"/></a><br/>
	   <xsl:for-each select="section2">

          <xsl:variable name="S2"><xsl:call-template name="setS2"/></xsl:variable>
	      &sp;&sp;<a href="{concat($S1FILE, '#s', $S2)}"><xsl:value-of select="concat($S2, @title)"/></a><br/>
	      <xsl:for-each select="section3">

            <xsl:variable name="S3"><xsl:call-template name="setS3"/></xsl:variable>
	          &sp;&sp;&sp;&sp;<a href="{concat($S1FILE, '#s', $S3)}"><xsl:value-of select="concat($S3, @title)"/></a><br/>

	        <xsl:for-each select="section4">

               <xsl:variable name="S4"><xsl:call-template name="setS4"/></xsl:variable>
	           &sp;&sp;&sp;&sp;&sp;&sp;<a href="{concat($S1FILE, '#s', $S4)}"><xsl:value-of select="concat($S4, @title)"/></a><br/>

	           <xsl:for-each select="section5">

                 <xsl:variable name="S5"><xsl:call-template name="setS5"/></xsl:variable>
	             &sp;&sp;&sp;&sp;&sp;&sp;&sp;&sp;<a href="{concat($S1FILE, '#s', $S5)}"><xsl:value-of select="concat($S5, @title)"/></a><br/>

	             <xsl:for-each select="section6">

                   <xsl:variable name="S6"><xsl:call-template name="setS6"/></xsl:variable>
	               &sp;&sp;&sp;&sp;&sp;&sp;&sp;&sp;&sp;&sp;<a href="{concat($S1FILE, '#s', $S6)}"><xsl:value-of select="concat($S6, @title)"/></a><br/>

	               <xsl:for-each select="section7">

                     <xsl:variable name="S7"><xsl:call-template name="setS7"/></xsl:variable>
	                  &sp;&sp;&sp;&sp;&sp;&sp;&sp;&sp;&sp;&sp;&sp;&sp;<a href="{concat($S1FILE, '#s', $S7)}"><xsl:value-of select="concat($S7, @title)"/></a><br/>


	                 <xsl:for-each select="section8">

                       <xsl:variable name="S8"><xsl:call-template name="setS8"/></xsl:variable>
	                  &sp;&sp;&sp;&sp;&sp;&sp;&sp;&sp;&sp;&sp;&sp;&sp;&sp;&sp;<a href="{concat($S1FILE, '#s', $S8)}"><xsl:value-of select="concat($S8, @title)"/></a><br/>

	                 </xsl:for-each>
	               </xsl:for-each>
	             </xsl:for-each>

	           </xsl:for-each>
	        </xsl:for-each>

	    </xsl:for-each>

	    </xsl:for-each>
    </xsl:for-each>

	<xsl:if test="/doc/back">
		<p><a href="{$REFSFILE}">References</a></p>
	</xsl:if>

</xsl:template>

<!-- List of references -->
<xsl:template name="refs">
<h2>References</h2>
	<table border="0" cellpadding="8">
		<xsl:for-each select="/doc/back/reference-list/reference-item">
		  <xsl:variable name="anchorId" select="@id" />
		  <xsl:variable name="destFile" select="java:nl.justobjects.xbook.XSLTHelper.getVar('destFile')" />
		  <xsl:variable name="dummy" select="java:nl.justobjects.xbook.XSLTHelper.putAnchor($anchorId, $REFSFILE)" />
			<tr>
				<td valign="top">
					<span class="MAIN"><a name="{@id}"/>[<xsl:value-of select="@id"/>]</span>
				</td>
				<td valign="top">
					<div class="MAIN">
						<xsl:apply-templates/>
					</div>
				</td>
			</tr>
		</xsl:for-each>
	</table>
</xsl:template>

<!--
	Draw navigation links check the number of the section
	and see if there's a prev or a next.
-->
<xsl:template name="nav">
	<table border="0"  cellpadding="8" >
		<tr>
 			<td>
				<div class="NAV">
				<xsl:if test="position() != 1">
					<a href="{concat($BASEFILE, '-s', position() - 1,'.html')}">Previous</a> |
				</xsl:if>
				<a href="{$COVERFILE}">Up</a>
				<xsl:if test="position() != last()">
					| <a href="{concat($BASEFILE, '-s', position() + 1,'.html')}">Next</a>
				</xsl:if>
				</div>
			</td>
 			<td>
 			   <i><div class="NAV"><xsl:value-of select="/doc/front/title"/></div></i>
			</td>
 			<td>
 			   	<div class="NAV">
					<a href="{$TOCFILE}">TOC</a>
					<xsl:if test="/doc/back">
						| <a href="{$REFSFILE}">Refs</a>
					</xsl:if>
				</div>
			</td>
		</tr>
	</table>
</xsl:template>

<xsl:template name="head">
	<xsl:param name="TITLE" select="'NO TITLE'"/>
     <head>
      <xsl:comment>Generated by XBook. Do not edit!!!</xsl:comment>
      <xsl:comment>Author: Just van den Broecke</xsl:comment>
      <xsl:comment>Email: just@justobjects.nl</xsl:comment>
      <xsl:comment>See www.justobjects.nl for more info</xsl:comment>

      <title><xsl:value-of select="$TITLE"/></title>
      <meta HTTP-EQUIV="Pragma" CONTENT="no-cache"/>
      <style type="text/css" ID="DocStyles">
	      <xsl:value-of select="document($STYLEFILE)" />
      </style>
     </head>
</xsl:template>

<xsl:template name="setS1">
  <xsl:number level="multiple" count="section1" format="1."/>
</xsl:template>

<xsl:template name="setS2">
  <xsl:number level="multiple" count="section1|section2" format="1."/>
</xsl:template>

<xsl:template name="setS3">
  <xsl:number level="multiple" count="section1|section2|section3" format="1."/>
</xsl:template>

<xsl:template name="setS4">
  <xsl:number level="multiple" count="section1|section2|section3|section4" format="1."/>
</xsl:template>

<xsl:template name="setS5">
  <xsl:number level="multiple" count="section1|section2|section3|section4|section5" format="1."/>
</xsl:template>

<xsl:template name="setS6">
  <xsl:number level="multiple" count="section1|section2|section3|section4|section5|section6" format="1."/>
</xsl:template>

<xsl:template name="setS7">
  <xsl:number level="multiple" count="section1|section2|section3|section4|section5|section6|section7" format="1."/>
</xsl:template>

<xsl:template name="setS8">
  <xsl:number level="multiple" count="section1|section2|section3|section4|section5|section6|section7|section8" format="1."/>
</xsl:template>


</xsl:stylesheet>

