<?xml version="1.0"?>



<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	version="1.1"
	xmlns:java="http://xml.apache.org/xslt/java"
	exclude-result-prefixes="java"
>

 <xsl:output method="html" indent="yes" encoding="ISO-8859-1" />
<xsl:param name="OUTDIR" select="'.'"/>

	<!--
  XSL for simple HTML-like formatting; typically imported by other XSL files
-->

<xsl:template match="para">
  <P>
    <xsl:apply-templates/>
  </P>
</xsl:template>

<xsl:template match="break">
  <br/><xsl:apply-templates/>
</xsl:template>

<xsl:template match="strong">
  <B><I>
    <xsl:apply-templates/>
  </I></B>
</xsl:template>

<xsl:template match="bold">
  <B>
    <xsl:apply-templates/>
  </B>
</xsl:template>

<xsl:template match="italic">
  <I>
    <xsl:apply-templates/>
  </I>
</xsl:template>

<xsl:template match="center">
  <CENTER>
    <xsl:apply-templates/>
  </CENTER>
</xsl:template>

<!-- code listing -->
<xsl:template match="listing">
<table cellspacing="0" cellpadding="1" border="0" bgcolor="black">
    <tr>
        <td>
            <table cellspacing="0" cellpadding="20" border="0" bgcolor="#F0F0F0" width="100%">
                <tr>
                     <td>
                       <pre>
                         <div class="LISTING">
                           	 <xsl:apply-templates/>
						</div>
                      </pre>
                    </td>
                </tr>
            </table>
        </td>
    </tr>
</table>
</xsl:template>

<!-- inline code -->
<xsl:template match="code">
  <FONT FACE="courier">
      <xsl:apply-templates/>
  </FONT>
</xsl:template>

<xsl:template match="as-is">
  <PRE>
    <xsl:apply-templates/>
  </PRE>
</xsl:template>


<!-- Inline image -->
<xsl:template match="image">
  <IMG src="{@href}" border="0"/>
</xsl:template>

<!-- Like HTML anchor -->
<xsl:template match="anchor">
	<xsl:call-template name="processAnchor">
		<xsl:with-param name="ANCHORID" select="@id"/>
	</xsl:call-template> 
</xsl:template>

<!-- Internal HTML link -->
<xsl:template match="link[starts-with(@href, '#')]">
  <!-- Communicate that we have a file with an external link such that it can be processed later. -->
  <xsl:variable name="anchorId" select="@href" />
  <xsl:variable name="destFile" select="java:nl.justobjects.xbook.XSLTHelper.getVar('destFile')" />
  <xsl:variable name="dummy"  select="java:nl.justobjects.xbook.XSLTHelper.putInternalLinkRef($anchorId, concat($OUTDIR, '/', $destFile))" />

  <A CLASS="INTLINK" href="{@href}" target="{@target}">
    <xsl:apply-templates/>
  </A>
</xsl:template>

<!-- External HTML link -->
<xsl:template match="link">
  <A CLASS="EXTLINK" href="{@href}" target="{@target}">
    <xsl:apply-templates/>
  </A>
</xsl:template>

<xsl:template match="list">
  <UL><xsl:apply-templates/></UL>
</xsl:template>

<xsl:template match="sequence">
  <OL><xsl:apply-templates/></OL>
</xsl:template>

<xsl:template match="list/item">
  <LI><xsl:apply-templates/></LI>
</xsl:template>

<xsl:template match="sequence/step">
  <LI><xsl:apply-templates/></LI>
</xsl:template>

<!-- Definition list implemented through TABLE -->
<xsl:template match="dictionary">
     <table border="0" cellspacing="0" cellpadding="4">
         <xsl:apply-templates/>
     </table>
</xsl:template>

<!-- Definition list single item -->
<xsl:template match="dictionary/defitem">
          <tr>
            <xsl:apply-templates/>
	 </tr>
</xsl:template>

<!-- Definition list term to be defined. Use same style as a TABLE1 -->
<xsl:template match="defitem/term">
         <td align="left" valign="top">
	  <div class="MAIN">
              <xsl:apply-templates/>
          </div>
	</td>
</xsl:template>

<!-- Definition list definition of term. Use same style as a TABLE1  -->
<xsl:template match="defitem/def">
	<td align="left" valign="top">
	  <div class="MAIN">
              <xsl:apply-templates/>
          </div>
	</td>
</xsl:template>

<!-- A simple table -->
<xsl:template match="table1[@border='false']">
     <table border="0" cellspacing="0" cellpadding="4">
      <xsl:apply-templates/>
     </table>
</xsl:template>

<!-- A simple table with border -->
<xsl:template match="table1[@border='true']">
     <table border="1" cellspacing="0" cellpadding="8">
      <xsl:apply-templates/>
     </table>
</xsl:template>

<xsl:template match="table1/row">
	<tr>
      <xsl:apply-templates/>
	</tr>
</xsl:template>

<xsl:template match="row/cell">
	<td align="left" colspan="{@colspan}" rowspan="{@rowspan}">
	<div class="MAIN">
	       <xsl:apply-templates/>
	  </div>
	</td>
</xsl:template>

<!-- Transform sections (NOTE: may be overruled, e.g. in doc2html.xsl) -->
<xsl:template match="section1" priority="1" >
  <a><xsl:attribute name="name" ><xsl:value-of select="@id"/></xsl:attribute></a>
  <h1><xsl:value-of select="@title"/></h1>
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="section2" priority="1" >
  <a><xsl:attribute name="name" ><xsl:value-of select="@id"/></xsl:attribute></a>
  <h2><xsl:value-of select="@title"/></h2>
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="section3" priority="1" >
  <a><xsl:attribute name="name" ><xsl:value-of select="@id"/></xsl:attribute></a>
  <h3><xsl:value-of select="@title"/></h3>
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="section4" priority="1">
  <a><xsl:attribute name="name" ><xsl:value-of select="@id"/></xsl:attribute></a>
  <h4><xsl:value-of select="@title"/></h4>
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="section5" priority="1">
  <a><xsl:attribute name="name" ><xsl:value-of select="@id"/></xsl:attribute></a>
  <h5><xsl:value-of select="@title"/></h5>
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="section6" priority="1">
  <a><xsl:attribute name="name" ><xsl:value-of select="@id"/></xsl:attribute></a>
  <h6><xsl:value-of select="@title"/></h6>
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="section7" priority="1">
  <a><xsl:attribute name="name" ><xsl:value-of select="@id"/></xsl:attribute></a>
  <b><i><xsl:value-of select="@title"/></i></b>
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="section8" priority="1">
  <a><xsl:attribute name="name" ><xsl:value-of select="@id"/></xsl:attribute></a>
  <i><xsl:value-of select="@title"/></i>
  <xsl:apply-templates/>
</xsl:template>

<!-- A split section into left right boxes -->
<xsl:template match="split">
        <table align="middle" cellpadding="4" cellspacing="4" width="95%">	<tr>
          <td width="45%" align="left" valign="top">
          <div class="MAIN">
              <xsl:apply-templates select="left"/>
	  </div>
	  </td>
          <td width="50%" align="left" valign="top">
          <div class="MAIN">
            <xsl:apply-templates select="right"/>
	  </div>
          </td>
	</tr>
     </table>
</xsl:template>

<xsl:template match="split/left|split/right">
      <xsl:apply-templates/>
</xsl:template>

<xsl:template match="xhtml">
      <xsl:copy-of select="./*"/>
</xsl:template>

<!-- START CALLABLE TEMPLATES -->

<!-- Process an anchor into an HTML A tag and store it for later resolution into XSLTHelper. -->
<xsl:template name="processAnchor">
   <!-- Default value if no ANCHORID provided. Somehow this is not set (just an empty string...) -->
  <xsl:param name="ANCHORID" select="'NULLANCHORID'"/> 

  
  <!-- Store the anchor for later post-processing all links to it. -->
  <xsl:variable name="destFile" select="java:nl.justobjects.xbook.XSLTHelper.getVar('destFile')" />
  <xsl:variable name="anchorId"  select="java:nl.justobjects.xbook.XSLTHelper.putAnchor($ANCHORID, $destFile)" /> 

  <!-- Output the HTML "A" tag with the value of the anchor. -->
  <a name="{$anchorId}" />

</xsl:template>


</xsl:stylesheet>