/**
 * This software is (c) Copyright Just Objects 1998. All Rights Reserved.
 *
 * File: ChatPanel.java
 * Date     Author    Changes
 * 980803   JustB     created
 *
 **/
package nl.justobjects.toolkit.awt;

import java.awt.*;

public class ChatPanel extends Panel {

	private TextField inputTextField = new TextField("<Your text here>", 50);
	private TextField nameTextField = new TextField("<Your name>", 12);
	private TextArea outputTextArea = new TextArea(20, 50);
	private List participantList = new List(20, false);
	private Panel cardPanel;
	private ChatPanelListener chatPanelListener = null;
	private Button quitButton = new Button("Quit");
	private Button joinButton = new Button("Join");
	final static String MSGPANEL = "MSGPANEL";
	final static String JOINPANEL = "JOINPANEL";
	String myName = "";

	public ChatPanel() {
		initLayout();
	}

	protected void initLayout() {
		// make GUI layout
		setBackground(Color.gray);
		setForeground(Color.blue);
		setLayout(new BorderLayout());

		participantList.setBackground(Color.lightGray);

		outputTextArea.setForeground(Color.blue);
		outputTextArea.setBackground(Color.white);
		outputTextArea.setEditable(false);


		Panel msgPanel = new Panel();
		msgPanel.add(inputTextField);
		msgPanel.add(quitButton);

		Panel joinPanel = new Panel();
		joinPanel.add(new Label("Name"));
		joinPanel.add(nameTextField);
		joinPanel.add(joinButton);

		cardPanel = new Panel();
		cardPanel.setLayout(new CardLayout());
		cardPanel.add(JOINPANEL, joinPanel);
		cardPanel.add(MSGPANEL, msgPanel);
		switchPanel(JOINPANEL);

		add("South", cardPanel);
		add("Center", outputTextArea);
		add("East", participantList);
		show();
	}

	// incoming text message from one of the participants
	synchronized public void addMessage(String from, String message) {
		outputTextArea.appendText(from + " : " + message + "\n");
	}

	// incoming text message from one of the participants
	synchronized public void addMessage(String message) {
		outputTextArea.appendText(message + "\n");
	}

	synchronized public void addParticipant(String name) {
		try {
			removeParticipant(name);
		} catch (Exception e) {
		}
		participantList.addItem(name);
	}


	synchronized public void removeParticipant(String name) {
		int itemCount = participantList.countItems();
		for (int i = 0; i < itemCount; i++) {
			if (participantList.getItem(i).equals(name)) {
				participantList.delItem(i);
				break;
			}
		}
	}


	// add listener for messages typed by local user
	synchronized public void addListener(ChatPanelListener listener) {
		chatPanelListener = listener;
	}

	// remove listener for messages typed by local user
	synchronized public void removeListener(ChatPanelListener listener) {
		chatPanelListener = null;
	}

	// simple JDK1.0.2-style action handler
	public boolean action(Event evt, Object what) {
		if (chatPanelListener == null) {
			return false;
		}

		// push entered text to server
		if (evt.target == inputTextField) {
			chatPanelListener.messageTyped(inputTextField.getText());
			inputTextField.setText("");
			return true;
		} else if (evt.target == joinButton || evt.target == nameTextField) {
			myName = nameTextField.getText();
			if (myName != null && !"".equals(myName)) {
				chatPanelListener.join(myName);
				nameTextField.setText("");
				switchPanel(MSGPANEL);
			}
			return true;
		} else if (evt.target == quitButton) {
			chatPanelListener.quit();
			participantList.clear();
			outputTextArea.setText("");
			switchPanel(JOINPANEL);
			return true;
		}

		// action OK
		return true;
	}

	protected void switchPanel(String toPanelName) {
		((CardLayout) cardPanel.getLayout()).show(cardPanel, (String) toPanelName);
	}
}