/****************************************************************
 * Copyright (C)2000 - Just van den Broecke - See license below *
 ****************************************************************/

package nl.justobjects.toolkit.collection;

import java.util.Vector;

/**
 * Data structure for bidirectional map (N-M mapping).
 *
 * @version $Id: BiMap.java,v 1.3 2003/01/06 00:23:48 just Exp $
 * @author Just van den Broecke - Just Objects B.V. &copy;
 */
public class BiMap {
	private Vector entries;

	public BiMap() {
		entries = new Vector();
	}

	public void addEntry(String anA, String aB) {
		entries.addElement(new BiMapEntry(anA, aB));
	}

	public boolean hasEntry(String anA, String aB) {
		BiMapEntry nextEntry;
		for (int i = 0; i < entries.size(); i++) {
			nextEntry = (BiMapEntry) entries.elementAt(i);
			if (nextEntry.A.equals(anA) && nextEntry.B.equals(aB)) {
				return true;
			}
		}
		return false;
	}

	public Vector getBsForA(String anA) {
		Vector Bs = new Vector(12);

		BiMapEntry nextEntry;
		for (int i = 0; i < entries.size(); i++) {
			nextEntry = (BiMapEntry) entries.elementAt(i);
			if (nextEntry.A.equals(anA)) {
				Bs.addElement(nextEntry.B);
			}
		}

		return Bs;
	}

	public Vector getAsForB(String aB) {
		Vector As = new Vector(12);

		BiMapEntry nextEntry;
		for (int i = 0; i < entries.size(); i++) {
			nextEntry = (BiMapEntry) entries.elementAt(i);
			if (nextEntry.B.equals(aB)) {
				As.addElement(nextEntry.A);
			}
		}

		return As;
	}

	public void removeA(String anA) {
		BiMapEntry nextEntry;
		for (int i = 0; i < entries.size(); i++) {
			nextEntry = (BiMapEntry) entries.elementAt(i);
			if (nextEntry.A.equals(anA)) {
				entries.removeElementAt(i);
			}
		}
	}

	public void removeB(String aB) {
		BiMapEntry nextEntry;
		for (int i = 0; i < entries.size(); i++) {
			nextEntry = (BiMapEntry) entries.elementAt(i);
			if (nextEntry.B.equals(aB)) {
				entries.removeElementAt(i);
			}
		}
	}

	public boolean removeEntry(String anA, String aB) {
		BiMapEntry nextEntry;
		for (int i = 0; i < entries.size(); i++) {
			nextEntry = (BiMapEntry) entries.elementAt(i);
			if (nextEntry.A.equals(anA) && nextEntry.B.equals(aB)) {
				entries.removeElementAt(i);
				return true;
			}
		}
		return false;
	}


	/** Represents single entry for N-M mapping A-to-B. */
	private static class BiMapEntry {

		public String A;
		public String B;

		public BiMapEntry(String anA, String aB) {
			A = anA;
			B = aB;
		}
	}
}

/*
 * $Log: BiMap.java,v $
 * Revision 1.3  2003/01/06 00:23:48  just
 * moved devenv to linux
 *
 * Revision 1.2  2002/11/14 20:25:19  just
 * reformat of code only
 *
 * Revision 1.1  2001/01/12 12:05:28  just
 * new
 *
 */

/*
   Copyright (C)2000 Just A. van den Broecke <just@justobjects.nl>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/