package nl.justobjects.toolkit.collection;

/**
 * Simple implementation of  CircularArray.
 * <p>
 * <b>Purpose</b><br>
 * This class can be used to store java.lang.Objects in a CircularArray.
 * <p>
 * <b>Implementation</b><br>
 * Implemented using an array.
 * <p>
 * <b>Examples</b><br>
 * <p>
 * <br>
 * $Source: /var/cvs/justobjects/toolkit/src/nl/justobjects/toolkit/collection/CircularArray.java,v $<p>
 *
 * @version $Id: CircularArray.java,v 1.5 2003/01/06 00:23:48 just Exp $
 * @author $Author: just $ - Just van den Broecke - Just Objects &copy;
 */
public class CircularArray {
	// default defining maximum CircularArray size
	int size = 0;
	int capacity = 16;
	Object[] array = null;
	int front, rear;

	public CircularArray() {
		this(16);
	}

	public CircularArray(int capacity) {
		this.capacity = capacity;
		array = new Object[capacity];
		front = rear = 0;
	}

	public void append(Object item) {
		array[front] = item;
		front = next(front);
		if (size == capacity) {
			rear = next(rear);
		} else {
			size++;
		}
	}

	public Object get(int index) {
		if (index > capacity - 1) {
			throw new ArrayIndexOutOfBoundsException();
		}

		return array[realIndex(index)];
	}

	public int getCapacity() {
		return capacity;
	}

	public int getSize() {
		return size;
	}

	public Object[] toArray() {
		Object[] result = new Object[getSize()];

		for (int i = 0; i < getSize(); i++) {
			result[i] = get(i);
		}
		return result;
	}

	private int next(int index) {
		return (index + 1) % capacity;
	}

	private int realIndex(int index) {
		return (rear + index) % capacity;
	}

	public void dump() {
		p("front=" + front);
		p("rear=" + rear);
		for (int i = 0; i < capacity; i++) {
			if (array[i] == null) {
				p("null");
			} else {
				p(array[i].toString());
			}
		}
	}

	public static void p(String s) {
		System.out.println(s);
	}

	public static void main(String[] args) {
		CircularArray ca = new CircularArray(5);
		for (int i = 0; i < 3; i++) {
			ca.append(new Integer(i * 10));
		}
		ca.dump();
		for (int i = 0; i < ca.getSize(); i++) {
			p("i=" + i + ": " + ca.get(i));
		}
		p("\nFULL");

		CircularArray ca2 = new CircularArray(5);
		for (int i = 0; i < 7; i++) {
			ca2.append(new Integer(i * 10));
		}
		ca2.dump();
		for (int i = 0; i < ca2.getSize(); i++) {
			p("i=" + i + ": " + ca2.get(i));
		}
	}
}