package nl.justobjects.toolkit.collection;

/**
 * Simple implementation of FIFO Queue.
 * <p>
 * <b>Purpose</b><br>
 * This class can be used to store java.lang.Objects in a FIFO queue.
 * <p>
 * <b>Implementation</b><br>
 * Implemented using an array.
 * <p>
 * <b>Examples</b><br>
 * <p>
 * <br>
 * $Source: /var/cvs/justobjects/toolkit/src/nl/justobjects/toolkit/collection/Queue.java,v $<p>
 *
 * @version $Id: Queue.java,v 1.3 2003/01/06 00:23:48 just Exp $
 * @author $Author: just $ - Just van den Broecke - Just Objects &copy;
 */
public class Queue {
	//constant defining maximum queue size
	int capacity = 32;
	Object[] queue = null;
	int front, rear;

	public Queue() {
		this(32);
	}

	public Queue(int capacity) {
		this.capacity = capacity;
		queue = new Object[capacity];
		front = rear = 0;
	}


	public boolean enQueue(Object item) {
		if (isFull()) {
			return false;
		}
		queue[rear] = item;
		rear = next(rear);
		return true;
	}

	public Object deQueue() {
		if (isEmpty()) {
			return null;
		}

		Object temp = queue[front];
		queue[front] = null;
		front = next(front);
		return temp;
	}

	public int getCapacity() {
		return capacity;
	}

	public int getFront() {
		return front;
	}

	public int getRear() {
		return rear;
	}

	public boolean isEmpty() {
		return front == rear;
	}

	public boolean isFull() {
		return (next(rear) == front);
	}

	private int next(int index) {
		return (index + 1 < capacity ? index + 1 : 0);
	}
}