/****************************************************************
 * Copyright (C)2000 - Just van den Broecke - See license below *
 ****************************************************************/

package nl.justobjects.xbook;

import nl.justobjects.toolkit.io.IO;

/**
 * Generates initial album XML file from images directory.
 * <p>
 * <b>Purpose</b><br>
 * <p>
 * Generate an initial file from an images assets directory.
 * <b>Implementation</b><br>
 * Plain string output. Not yet using Document etc.
 * <p>
 * <b>Examples</b><br>
 * java nl.justobjects.xbook.Dir2AlbumXML assets/images myalbum.xml
 * <p>
 * <br>
 * $Source: /var/cvs/justobjects/xbook/src/nl/justobjects/xbook/Dir2AlbumXML.java,v $<p>
 *
 * @version $Revision: 1.3 $
 * @author $Author: just $ - Just van den Broecke - Just Objects &copy;
 * @since $Date: 2003/01/06 10:27:22 $
 * @see <package name.classname#method>
 */
public class Dir2AlbumXML {

	static public void p(String s) {
		System.out.println("Dir2AlbumXML: " + s);
	}

	static public void fatal(String what, Exception e) {
		p("ERROR - " + what + " exception =" + e);
		e.printStackTrace();
		System.exit(-1);
	}

	static public void main(String args[]) {

		if (args.length != 2) {
			p("Usage: Dir2AlbumXML <assets dir> <xml file>");
			System.exit(-1);
		}

		StringBuffer sb = new StringBuffer();

		try {
			sb.append("<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n");
			sb.append("<!DOCTYPE album SYSTEM \"nl/justobjects/xbook/rsc/dtd/album.dtd\" > \n");

			sb.append("<album>\n");

			// Generate default meta info.
			sb.append("  <cover>\n");
			sb.append("    <title>Your title here</title>\n");
			sb.append("    <author>JB</author>\n");
			sb.append("    <date>" + new java.util.Date().toString() + "</date>\n");
			sb.append("    <description>\n");
			sb.append("	      Your Description here\n");
			sb.append("    </description> \n");
			sb.append("  </cover> \n");

			// Start images section.
			sb.append("  <images>\n");

			// Get the list of images in source directory.
			String[] dirList = IO.dir2StringArray(args[0], null);

			// Make image element for each image
			for (int i = 0; i < dirList.length; i++) {
				sb.append("    <image title=\"" + dirList[i] + "\" file=\"" + dirList[i] + "\" />\n");
			}

			sb.append("  </images>\n");
			sb.append("</album>\n");

			// Write the album into output file
			IO.StringToFile(args[1], sb.toString());

		}
		catch (Exception e) {
			fatal("Exception in process()", e);
		}

		System.exit(0);
	}
}

/*
 * $Log: Dir2AlbumXML.java,v $
 * Revision 1.3  2003/01/06 10:27:22  just
 * removed Arial fonts from default styles
 *
 * Revision 1.2  2002/07/28 15:09:25  just
 * comments
 *
 * Revision 1.1  2002/07/28 15:05:12  just
 * new
 */

/*
   Copyright (C)2002 Just A. van den Broecke <just@justobjects.nl>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/