/****************************************************************
 * Copyright (C)2000 - Just van den Broecke - See license below *
 ****************************************************************/

package nl.justobjects.amuse.core;

import nl.justobjects.jox.Element;

/** Default implementation of Amulet base class. */
//{api
abstract public class Amulet implements SubjectSpace {
	private SubjectSpaceContext context;
	boolean debug = false;

	public void activate() throws AmuseException {
		logEvent(null, "activate");
	}

	public boolean isDebug() {
		return debug;
	}

	public Element getState() {
		return null;
	}

	public SubjectSpaceContext getContext() {
		return context;
	}

	public void join(SpaceAgent spaceAgent, Element command) throws AmuseException {
		logEvent(spaceAgent, "join");
	}

	public void leave(SpaceAgent spaceAgent, Element command) throws AmuseException {
		logEvent(spaceAgent, "leave");
	}

	public void passivate() throws AmuseException {
		logEvent(null, "passivate");
	}

	abstract public void accept(SpaceAgent spaceAgentFrom, Element command) throws AmuseException;

	public void init(SubjectSpaceContext theContext) throws AmuseException {
		context = theContext;
	}

	public void start() throws AmuseException {
		logEvent(null, "start");
		if ("true".equals(getContext().getConfig().getAttr("debug"))) {
			setDebug(true);
		}
	}

	public void stop() throws AmuseException {
		logEvent(null, "stop");
	}

	public void updateAgent(SpaceAgent spaceAgent) {
	}

	protected void dbg(SpaceAgent spaceAgent, String s) {
		if (debug) {
			String id = "none";
			String name = "unknown";
			if (spaceAgent != null) {
				id = spaceAgent.getId();
				name = spaceAgent.getAttr("name");
			}
			System.out.println(getContext().getId() + ": " + "agent= " + name + " " + s);
		}
	}
	protected void dbg(String s) {
		dbg(null, s);
	}

	protected void logEvent(SpaceAgent spaceAgent, String what) {
		context.logEvent(spaceAgent, what);
	}

	protected void logWarning(SpaceAgent spaceAgent, String what) {
		context.logWarning(spaceAgent, what);
	}

	protected void setDebug(boolean b) {
		debug = b;
	}
}
//}api
/*
 * $Log: Amulet.java,v $
 * Revision 1.1  2002/09/30 22:25:50  just
 * no message
 *
 * Revision 1.1  2002/06/18 11:05:18  just
 * no message
 *
 * Revision 1.10  2002/05/16 14:37:51  just
 * chnages for masterserver (httpattr) and filerelay
 *
 * Revision 1.9  2002/04/14 23:32:35  just
 * no message
 *
 * Revision 1.8  2002/03/21 16:45:21  just
 * stuff forserver  shutdown and status
 *
 * Revision 1.7  2002/02/14 10:58:58  just
 * fixes for UDP output probing
 *
 * Revision 1.6  2001/11/22 14:22:37  just
 * changes for threading stability
 *
 * Revision 1.5  2001/10/25 14:25:31  kstroke
 * improvements on record/playback
 *
 * Revision 1.4  2001/09/06 23:29:34  kstroke
 * further development
 *
 * Revision 1.3  2001/08/30 15:51:14  kstroke
 * further development
 *
 * Revision 1.2  2001/05/10 00:36:58  just
 * many changes for config and name changes (AmuseException)
 *
 * Revision 1.1  2001/02/22 13:06:21  just
 * package change from .space to .core
 *
 * Revision 1.2  2001/02/04 16:38:01  just
 * no message
 *
 * Revision 1.1  2001/02/04 13:19:55  just
 * name change DefaultSubject to Amulet
 *
 * Revision 1.3  2001/01/28 14:26:40  just
 * added log methods
 *
 * Revision 1.2  2001/01/11 22:43:48  just
 * fixed debugging printing
 *
 * Revision 1.1  2001/01/11 17:00:25  just
 * new
 *
 *
 */

/*
   Copyright (C)2000 Just A. van den Broecke <just@justobjects.nl>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/